@@ -37,11 +37,13 @@ test_that("number_folder works", {
   ijtiff::write_tif(img, "50.tif")
   ijtiff::write_tif(img, "50again.tif")
   ijtiff::write_tif(array(4, dim = rep(3, 4)), "const.tif")
-  expect_error(number_folder(def = "rory", detrend = FALSE),
-               paste0(
-                 "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
-                 "'rory'`."
-               ))
+  expect_error(
+    number_folder(def = "rory", detrend = FALSE),
+    paste0(
+      "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
+      "'rory'`."
+    )
+  )
   number_folder(def = "N", detrend = FALSE)
   expect_true(
     all(c(
@@ -56,11 +58,13 @@ test_that("number_folder works", {
   )
   filesstrings::create_dir("tempwithintemp")
   ijtiff::write_tif(img, "tempwithintemp/50.tif")
-  expect_error(number_file("tempwithintemp/50.tif", def = "rory"),
-               paste0(
-                 "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
-                 "'rory'`."
-               ))
+  expect_error(
+    number_file("tempwithintemp/50.tif", def = "rory"),
+    paste0(
+      "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
+      "'rory'`."
+    )
+  )
   number_file("tempwithintemp/50.tif", def = "n")
   expect_true(stringr::str_detect(
     dir("tempwithintemp/number"),
@@ -100,7 +104,7 @@ test_that("number_timeseries works", {
     }
   )
   nts_overlapped <- number_timeseries(img, "N", dim(img)[4],
-                                          overlap = TRUE
+    overlap = TRUE
   )
   expect_equal(
     nts_overlapped %>% {
@@ -111,10 +115,10 @@ test_that("number_timeseries works", {
     }
   )
   expect_equal(median(nts, na.rm = TRUE), median(nts_overlapped, na.rm = TRUE),
-               tolerance = min(abs(c(
-                 median(nts, na.rm = TRUE),
-                 median(nts_overlapped, na.rm = TRUE)
-               ))) / 10
+    tolerance = min(abs(c(
+      median(nts, na.rm = TRUE),
+      median(nts_overlapped, na.rm = TRUE)
+    ))) / 10
   )
   nts <- number_timeseries(img, "n", 30,
     detrend = FALSE,
@@ -143,8 +147,8 @@ test_that("number_timeseries works", {
   )
   n <- number(two_channel_img, "n")
   nts_2ch <- number_timeseries(two_channel_img, "n",
-                                   dim(two_channel_img)[4],
-                                   detrend = FALSE
+    dim(two_channel_img)[4],
+    detrend = FALSE
   )
   expect_equal(
     nts_2ch %>% {
@@ -164,14 +168,16 @@ test_that("number_timeseries works", {
   ijtiff::write_tif(img, "50again.tif")
   filesstrings::create_dir("tempwithintemp")
   ijtiff::write_tif(img, "tempwithintemp/50.tif")
-  expect_error(number_timeseries_file("tempwithintemp/50.tif",
-                                      def = "rory",
-                                      frames_per_set = 10
-  ),
-               paste0(
-                 "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
-                 "'rory'`."
-               ))
+  expect_error(
+    number_timeseries_file("tempwithintemp/50.tif",
+      def = "rory",
+      frames_per_set = 10
+    ),
+    paste0(
+      "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
+      "'rory'`."
+    )
+  )
   number_timeseries_file("tempwithintemp/50.tif",
     def = "n",
     frames_per_set = 10
@@ -181,14 +187,15 @@ test_that("number_timeseries works", {
     "^50_number_n_contiguous_timeseries.*tif$"
   ))
   filesstrings::dir.remove("tempwithintemp")
-  expect_error(number_timeseries_folder(
-    def = "rory", thresh = "tri", frames_per_set = 20,
-    detrend = TRUE
-  ),
-  paste0(
-    "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
-    "'rory'`."
-  )
+  expect_error(
+    number_timeseries_folder(
+      def = "rory", thresh = "tri", frames_per_set = 20,
+      detrend = TRUE
+    ),
+    paste0(
+      "`def` must be one of 'N' or 'n.+You have used `def =\\s?",
+      "'rory'`."
+    )
   )
   number_timeseries_folder(
     def = "n", thresh = "tri", frames_per_set = 20,
@@ -206,14 +213,18 @@ test_that("number_timeseries works", {
     ),
     ".tif"
   )
-  ans1 <- stringr::str_replace(ans0, "5029", "5363")  # travis ubuntu
-  ans2 <- stringr::str_replace(ans0, "5029", "862")  # windows
-  ans3 <- stringr::str_replace(ans0,
-                               c("auto=0", "auto=5029"),
-                               c("auto=1600", "auto=3840"))  # rhub fedora
-  ans4 <- stringr::str_replace(ans0,
-                               c("auto=0", "auto=5029"),
-                               c("auto=5363", "auto=0"))  # rhub ubuntu
+  ans1 <- stringr::str_replace(ans0, "5029", "5363") # travis ubuntu
+  ans2 <- stringr::str_replace(ans0, "5029", "862") # windows
+  ans3 <- stringr::str_replace(
+    ans0,
+    c("auto=0", "auto=5029"),
+    c("auto=1600", "auto=3840")
+  ) # rhub fedora
+  ans4 <- stringr::str_replace(
+    ans0,
+    c("auto=0", "auto=5029"),
+    c("auto=5363", "auto=0")
+  ) # rhub ubuntu
   lfnts <- list.files("number_timeseries")
   if (all(lfnts %in% ans0)) {
     expect_true(all(lfnts %in% ans0))
